from typing import Mapping, Optional, Sequence
from urllib.parse import urlencode

from django.conf import settings
from django.urls import reverse


def social_reverse(
    viewname: str, args: Optional[Sequence] = None, kwargs: Optional[Mapping] = None
) -> str:
    social_namespace = getattr(settings, "SOCIAL_AUTH_URL_NAMESPACE", "social")
    social_viewname = f"{social_namespace}:{viewname}"

    return reverse(social_viewname, args=args, kwargs=kwargs)


def saml_begin_url(idp: str = "umich", params: Optional[Mapping] = None) -> str:
    base = social_reverse("begin", kwargs=dict(backend="saml"))
    url_params = dict(idp=idp)
    if params is not None:
        url_params.update(params)

    return f"{base}?{urlencode(url_params)}"
