# As identified at https://documentation.its.umich.edu/node/262
class SAMLAttributes:
    MCOMMUNITY_NAME = "displayName"
    FIRST_NAME = "givenName"
    LAST_NAME = "sn"
    PERSON_ENTITLEMENT = "eduPersonEntitlement"
    AFFILIATION = "eduPersonAffiliation"
    INSTITUTION_AFFILIATION = "eduPersonScopedAffiliation"
    EMAIL = "mail"
    PRINCIPAL_NAME = "eduPersonPrincipalName"
    EMPLOYEE_NUMBER = "employeeNumber"
    UNIQNAME = "uid"


NO_UID_ATTRIBUTE_MAP = {
    "attr_user_permanent_id": SAMLAttributes.PRINCIPAL_NAME,
    "attr_full_name": SAMLAttributes.MCOMMUNITY_NAME,
    "attr_first_name": SAMLAttributes.FIRST_NAME,
    "attr_last_name": SAMLAttributes.LAST_NAME,
    "attr_username": SAMLAttributes.PRINCIPAL_NAME,
    "attr_email": SAMLAttributes.EMAIL,
}

UID_ATTRIBUTE_MAP = {
    "attr_user_permanent_id": SAMLAttributes.UNIQNAME,
    "attr_full_name": SAMLAttributes.MCOMMUNITY_NAME,
    "attr_first_name": SAMLAttributes.FIRST_NAME,
    "attr_last_name": SAMLAttributes.LAST_NAME,
    "attr_username": SAMLAttributes.UNIQNAME,
    "attr_email": SAMLAttributes.EMAIL,
}

UMICH_IDP_BASE = {
    "entity_id": "https://shibboleth.umich.edu/idp/shibboleth",
    "url": "https://shibboleth.umich.edu/idp/profile/SAML2/Redirect/SSO",
    "slo_url": "https://shibboleth.umich.edu/idp/profile/SAML2/Redirect/SLO",
    "organization_name": "University of Michigan",
    "x509certMulti": {
        "signing": [
            """
                MIIDPDCCAiSgAwIBAgIVAKTsnSoDNC7AuF7I0MFTRrakT8UzMA0GCSqGSIb3DQEB
                BQUAMB8xHTAbBgNVBAMTFHNoaWJib2xldGgudW1pY2guZWR1MB4XDTA5MDMyNTE0
                MzcwMVoXDTI5MDMyNTE0MzcwMVowHzEdMBsGA1UEAxMUc2hpYmJvbGV0aC51bWlj
                aC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDhtn+rMsZLQXwO
                SGUnB4+S4lfo9UAvenGskm74puRzGBO9UB5QxPn8LIkHEloafvlWuYKOf8yVqFom
                /q+odD7wl+M66z0E+d0Ci5P2pw2ZaREymG6JMLg7kHuuXWKuxOZPsLcExFqqroF5
                p1NTVaNAT2F27+NXuTabW/p09Tn2H2FPnWhtaZ9PzFfj2Y7SRSPWxp/6KdPZ/rlv
                y9FVIpojwh0uQxPz/un22XMu7W+sw49vBKa4xgHv1TTrMIi83fMElEE4NVQuQc0X
                uT7J29+b+BRQnXLYvIbxJWVrSxXZIbgAirNaW3DYNocH3LweQSXSLOAmFlIMvJ5L
                bMa5BvhDAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNoaWJib2xldGgudW1pY2guZWR1
                hitodHRwczovL3NoaWJib2xldGgudW1pY2guZWR1L2lkcC9zaGliYm9sZXRoMB0G
                A1UdDgQWBBS99cFe6MAQ+FC7bKXUVybdWHsAFjANBgkqhkiG9w0BAQUFAAOCAQEA
                jqQuqBLJLw6OtPVs0V3ZPU/q09qzxpU4GWx+h/GCuex6oVYJmgXweK8vJd7R/pW1
                1LbspeQU1NIsO19k1YF8TZlhqYzbx4PQoDwMYsvl98NN9J1MdMt0I0tx23bT3egP
                WDGivFjtUra8t0VXjVu7opsRcd125wNBLglpk2tu7i7la87BzUDXpidX60KimfaC
                JZUi4F4cCLgSEdoliyfSn2Whqwbm2AGfH+77tyFMI2ZhKa9nmskThwmK12Y6ElnS
                9LmVd8q6AjVB3HnwguPOQjs9UBcxb9eeYwhhgUl11nyEmpvIUmYlGKLT/+ghVmTM
                6e4eBYMhFygzksi2hS6UIw==
            """,
            """
                MIIExzCCA6+gAwIBAgIUVHzqI0XmEfoxTGVN87fckM+iIpUwDQYJKoZIhvcNAQEL
                BQAwgcoxCzAJBgNVBAYTAlVTMREwDwYDVQQIDAhNaWNoaWdhbjESMBAGA1UEBwwJ
                QW5uIEFyYm9yMSMwIQYDVQQKDBpUaGUgVW5pdmVyc2l0eSBvZiBNaWNoaWdhbjEr
                MCkGA1UECwwiSVRTIElkZW50aXR5IGFuZCBBY2Nlc3MgTWFuYWdlbWVudDEdMBsG
                A1UEAwwUc2hpYmJvbGV0aC51bWljaC5lZHUxIzAhBgkqhkiG9w0BCQEWFHNoaWJi
                b2xldGhAdW1pY2guZWR1MB4XDTIwMDcxNjIwMjMxN1oXDTQwMDcxNTIwMjMxN1ow
                gcoxCzAJBgNVBAYTAlVTMREwDwYDVQQIDAhNaWNoaWdhbjESMBAGA1UEBwwJQW5u
                IEFyYm9yMSMwIQYDVQQKDBpUaGUgVW5pdmVyc2l0eSBvZiBNaWNoaWdhbjErMCkG
                A1UECwwiSVRTIElkZW50aXR5IGFuZCBBY2Nlc3MgTWFuYWdlbWVudDEdMBsGA1UE
                AwwUc2hpYmJvbGV0aC51bWljaC5lZHUxIzAhBgkqhkiG9w0BCQEWFHNoaWJib2xl
                dGhAdW1pY2guZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4bZ/
                qzLGS0F8DkhlJwePkuJX6PVAL3pxrJJu+KbkcxgTvVAeUMT5/CyJBxJaGn75VrmC
                jn/MlahaJv6vqHQ+8JfjOus9BPndAouT9qcNmWkRMphuiTC4O5B7rl1irsTmT7C3
                BMRaqq6BeadTU1WjQE9hdu/jV7k2m1v6dPU59h9hT51obWmfT8xX49mO0kUj1saf
                +inT2f65b8vRVSKaI8IdLkMT8/7p9tlzLu1vrMOPbwSmuMYB79U06zCIvN3zBJRB
                ODVULkHNF7k+ydvfm/gUUJ1y2LyG8SVla0sV2SG4AIqzWltw2DaHB9y8HkEl0izg
                JhZSDLyeS2zGuQb4QwIDAQABo4GiMIGfMB0GA1UdDgQWBBS99cFe6MAQ+FC7bKXU
                VybdWHsAFjAfBgNVHSMEGDAWgBS99cFe6MAQ+FC7bKXUVybdWHsAFjAPBgNVHRMB
                Af8EBTADAQH/MEwGA1UdEQRFMEOCFHNoaWJib2xldGgudW1pY2guZWR1hitodHRw
                czovL3NoaWJib2xldGgudW1pY2guZWR1L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3
                DQEBCwUAA4IBAQDcR8+UzM4aivTdSkbbx2mMpUN6ToGz9OO+zkkU35UlAC0gBntC
                dZtoyn2v7XBYM+tE6dV9DiqH7s6XLTKXEMDKHgwDF4q1WtXrdGNSPrn4m6n42ahK
                D4bSDKVSrlzj21exT9bfbVVswJvSRmJHfNuLoyNj49huoSNEedbIBLQZ0Gn/ncsc
                YAZDvmF8+opKpMjcrmHpC7TCup8zB1lkba+C82rPZ7w1Y94SjfBBOVEdhYiSGUH+
                x2Ti5SpSssQZW24fniIrE9PtibTr9d+piO0P1/5B6hpZtPkWC3mgtzAOafwMYDrY
                1DuUjvtcQOwvGT8kVxYjOcmLHeppBSeXXRRF
            """,
        ],
        "encryption": [
            """
                MIIDPDCCAiSgAwIBAgIVAM8TM5Ha6Czir5/UXyi7jOaIDHTjMA0GCSqGSIb3DQEB
                CwUAMB8xHTAbBgNVBAMMFHNoaWJib2xldGgudW1pY2guZWR1MB4XDTE1MDkwOTE2
                MzczM1oXDTM1MDkwOTE2MzczM1owHzEdMBsGA1UEAwwUc2hpYmJvbGV0aC51bWlj
                aC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDhwgg8rer6Sb8Q
                0h1TW3yBLRuGHNuBgnqBmYpOIAPvZMmVd7E5Uy7+/5TQ/fmVxONyPqGfwZ30OQ10
                tjh1x7N98+fkBVUgddIz9+/mejGoa8t1oJfgFNCODkRnNBW4KCZ6vgul5K9dp1DD
                IbAxaPnfihoKNbs2rrRPZCnE1m5qA9BNERI3oAmx3TUDY9Q+KSgxfafNeV4R2V9l
                r3Q1C2+DaTTRFT1r9Z6zfwBgluUnEWetw6kd/Mr07MpHeZXteRe8/30KYm7jdFr4
                YQT3Hw4Rrs0gVujDCJeUzPBc2oCm3Q4LkCYej83ORK7aVMai3h5d1sJ+i2Ae6+tq
                naR9xHxTAgMBAAGjbzBtMB0GA1UdDgQWBBSSOHMt6RMXaIzRomwpU7hxQPVrdjBM
                BgNVHREERTBDghRzaGliYm9sZXRoLnVtaWNoLmVkdYYraHR0cHM6Ly9zaGliYm9s
                ZXRoLnVtaWNoLmVkdS9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEA
                d+u9xmOSiofg71PGm+NNvcLjUdIfwts8jrN3fz8HC0vBt80Ok5aBLQHDYv8yYTZG
                hjzFHAQKT20yAv4RgMVhyjoSGRY3j5KGiVbr1UJjsmg6zdfzKhNYvwsWpPYu1KQB
                uxK+YXfCRnBtD3PpxfIL4vhjtNI7ZYSzssJ7ywz9sj5dfoJxqClxaJkqUtwVcvT9
                wTlnxaUonkQ1GueeBZiMTvu7gK/LJUANGRk/hxcSjkdQX/VN6rCf/WvcBbBK1tEw
                tFW3a4T+V/Meg8o1/M3rmyaBJOnjRQWtU8YabPgkifoFh585EU3hpD/9sRrAB9Z9
                mw/4tAnwG/Jud63/M46a9w==
            """,
        ],
    },
}

UMICH_STAGING_IDP_BASE = {
    "entity_id": "https://shib-idp-staging.dsc.umich.edu/idp/shibboleth",
    "url": "https://shib-idp-staging.dsc.umich.edu/idp/profile/SAML2/Redirect/SSO",
    "slo_url": "https://shib-idp-staging.dsc.umich.edu/idp/profile/SAML2/Redirect/SLO",
    "organization_name": "University of Michigan",
    "x509cert": {
        "signing": [
            """
                MIIEZjCCAs6gAwIBAgIVAKPRJ3kOnVLto2br+gW9zUCYU5IFMA0GCSqGSIb3DQEB
                CwUAMCkxJzAlBgNVBAMMHnNoaWItaWRwLXN0YWdpbmcuZHNjLnVtaWNoLmVkdTAe
                Fw0yMDA3MjMxNzUxMTRaFw00MDA3MjMxNzUxMTRaMCkxJzAlBgNVBAMMHnNoaWIt
                aWRwLXN0YWdpbmcuZHNjLnVtaWNoLmVkdTCCAaIwDQYJKoZIhvcNAQEBBQADggGP
                ADCCAYoCggGBAImT+HFou5mtmwD6OY7mC9Yufi/L8bsJVC3hFfdrWGD2mJCg3aFg
                aH1wOHq1SDsqcAD6hpYoy6VZvhtqAC0108IOJRkK2USKC24+Y2iAEqDwr80sl6Z+
                4Szqpvm4DGWXvHMeO/J7danUOMZk6r6GaeOV2u7Bv1zf11S/Jjd2uzfquQkJvFQc
                EdiN2NgbBY9YRS70TyNASFEmzqp630rWjfuXK6ehNbRIpVcwn2dLV7M3lSMG/PVQ
                aymLODAUC2CUI7zDfG6jdaYgDhUtr9eXEsFRZXOUFQykhJco7VvWNXOD21tKS6oY
                JBimcWJlUp3JW6mlhjN6FQa2UEsReFzAEJiyIwc43rZa69ksy/U/3eWBfqiBCW7w
                vPh5xpcBilrau4yBk8xEKM+na8QnLpQN4Pm07bY7c6QS4FMDvhc0E8oryvD/omiT
                WOMM2cQEBf9AEtEXg9Pw/AXhQvBPtMUNBzdXvDQmUkIWgESnOR13w2mlYtu2CuT/
                T7OfJSsXcKyxWQIDAQABo4GEMIGBMB0GA1UdDgQWBBTtLSfzqy39b+TCGkxBz7A9
                dnETwTBgBgNVHREEWTBXgh5zaGliLWlkcC1zdGFnaW5nLmRzYy51bWljaC5lZHWG
                NWh0dHBzOi8vc2hpYi1pZHAtc3RhZ2luZy5kc2MudW1pY2guZWR1L2lkcC9zaGli
                Ym9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBgQB2fTncJdNYR2U9ZhGGB3HrNoykkqK0
                wOCA5/42S4bxHbolrMcdM0R9EPFj09Zi3LvGcUftULYurRVe2ki6JWAfUd6lRDrr
                oD6hr08K/rxq8qpgNO71QGy7VI5sfBhm6W0ZzJUz2Qa8OatRpttvcpJPDZcXnW1i
                Fzr9/BNc94YCSjbswYcjkMleRyWlsAcnbTwhUoe3WqLeiwwGrqr1L39Pb1uafC9J
                AYz97A4avAVn1kKID6j9v1CMZkqBY5bSiJpMN7iPqHqOlqhUWxNAlIapC0nXX3hi
                3Ls0b36AcFtiVHXNYPPpmxTNWAY2re54mo2k1SKOv1KPHw5yfonQw7Ow8i6njv2h
                84Y3Gj6YIU1doCFitp5vn5meAE55ztLyfS6H8vUybOpjP/kO1pFMyjXkWEU/bRUy
                aZZzNhqhz9suh//ZdugfPgTSJ6JA4ZibvgiAafRtur67NHBZmcXjcxfxHLNNbIIz
                kZD+rWEPkoug3Cu6cbanjTn2rliGHgYNKVg=
            """,
        ],
        "encryption": [
            """
                MIIEZjCCAs6gAwIBAgIVAOIZ/xNXb+Yyvr4nW5JAldgIA/JSMA0GCSqGSIb3DQEB
                CwUAMCkxJzAlBgNVBAMMHnNoaWItaWRwLXN0YWdpbmcuZHNjLnVtaWNoLmVkdTAe
                Fw0yMDA3MjMxNzUwNTBaFw00MDA3MjMxNzUwNTBaMCkxJzAlBgNVBAMMHnNoaWIt
                aWRwLXN0YWdpbmcuZHNjLnVtaWNoLmVkdTCCAaIwDQYJKoZIhvcNAQEBBQADggGP
                ADCCAYoCggGBAJCqcHx1BkDnyQwDkZIm32CHFGkCStFRSZ2vnc0IQZBwDQvUP3Ks
                W6VHShJROeOfnC62pEbEbX7pAv29mVqbUkVTCSy4MYug1Kl2vdv1jwWLtQComSv6
                Mtinctg0y0CGet4PvX4FnDk0HCpRzJw3Fc2P3DJt2wVZS8VK+HEJIrWE4F1vKq4T
                fW4UvF+Iny5cRNqqIGXCsTX4ezBjEok4wpQ5tagl8NCg/Q9YrzJOXVvznPeYY/am
                eZop5NtqXMHQe2WcvGaNfT4E+jv8zxJagQ+mMGvReoPr+TYq/qK4TVc6GRqOi2iq
                Jqvhdzun+AElHp2xcjqJHk2shKJgKCw4VlovtINwOhddLHZAqK5Ofx7SPfDw+6e/
                hwklZDpcQd0g+SW1VOENUeG69gns2Trh2xA1saSr6e79QnVltfiTRSF4oXsLQxi9
                EVnPDL+qLCm+WwyGwRRsSRP1BrygXpuNagPxsqFrSHhGEzpukOFwB2IfIWhpn1Pm
                fY7cjgpHv9pY5QIDAQABo4GEMIGBMB0GA1UdDgQWBBQoLi0415zgsSo6aPgAGaab
                oVRyajBgBgNVHREEWTBXgh5zaGliLWlkcC1zdGFnaW5nLmRzYy51bWljaC5lZHWG
                NWh0dHBzOi8vc2hpYi1pZHAtc3RhZ2luZy5kc2MudW1pY2guZWR1L2lkcC9zaGli
                Ym9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBgQB11i9KuBvx+XC5MN3jM9rjDl+azJta
                8LgaSq/3JxG591Bz6xKboirCjtFvdsI+nyVnHI53r2k0wNjAtWHbrWFX3h0TE2yX
                RcrDgI4Gy3ysW08AxNuf8efhsoERHVo1TXAwqVH6QIdBtq7f/oiGUt/iUaXN+Nn9
                wZxb3pMARl8aUy6Tw0Kz2RY7+lvKl1RhtY1Va3qYJBTUGKRUP1lkzTQrPxcNWmKN
                Dp3wCGAsG9YN28yLUqoetARP4f+fknA4SEJEpKmeRdhywtBlYgy6Hv/nYJC+tveD
                BOeyujij7yfWyT17plqpyrtu7xk+EX3fDyKG+mY0VP7CStixM3YDPh9oIHNkX3of
                nFegb7u4niph1DuG1HbAFEQiFGPFnnDcvlbZI2D47LKK90FzWVXDRb5FWBuMqR6M
                oYmoTjjJcNOFDFt0UZRlpvLKcRzjlJf1BOAbZO3gSd/MxqwJLw19F09CJOP2UV7u
                ERFcHms3H052rzluwuBEX+toJrxOLvKo72I=
            """,
        ],
    },
}


UMICH_IDP = {**UMICH_IDP_BASE, **NO_UID_ATTRIBUTE_MAP}
UMICH_STAGING_IDP = {**UMICH_STAGING_IDP_BASE, **NO_UID_ATTRIBUTE_MAP}
